PyXMake Developer Guide: PyXMake.VTL.sphinx Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.sphinx Namespace Reference

## Functions
| main (BuildID, masterfile, source=os.path.join(__pyc_core_path,"VTL","doc","mcd_legacy"), output=os.path.join(__pyc_core_path,"VTL","doc","mcd_legacy"), include=[os.path.join(__pyc_core_path), Utility.GetPyXMakePath()], scratch=VTL.Scratch, verbosity=2, **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Create documentations for PyXMake, PyCODAC and STMLab with Sphinx.
    Created on 05.08.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake, PyCODAC

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.sphinx.main | ( |  | BuildID,
|  |  | masterfile,
|  |  | source = os.path.join(__pyc_core_path,"VTL","doc","mcd_legacy"),
|  |  | output = os.path.join(__pyc_core_path,"VTL","doc","mcd_legacy"),
|  |  | include = [os.path.join(__pyc_core_path),Utility.GetPyXMakePath()],
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 52 of file sphinx.py.